Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/blenkernel/intern/texture.c')
-rw-r--r--source/blender/blenkernel/intern/texture.c8
1 files changed, 3 insertions, 5 deletions
diff --git a/source/blender/blenkernel/intern/texture.c b/source/blender/blenkernel/intern/texture.c
index 77416f4dd12..da3dea37220 100644
--- a/source/blender/blenkernel/intern/texture.c
+++ b/source/blender/blenkernel/intern/texture.c
@@ -1337,13 +1337,11 @@ int BKE_texture_dependsOnTime(const struct Tex *texture)
else if( texture->ima &&
ELEM(texture->ima->source, IMA_SRC_SEQUENCE, IMA_SRC_MOVIE)) {
return 1;
- }
-#if 0 // XXX old animation system
- else if(texture->ipo) {
- // assume any ipo means the texture is animated
+ }
+ else if(texture->adt) {
+ // assume anything in adt means the texture is animated
return 1;
}
-#endif // XXX old animation system
return 0;
}